#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://transmission.m0k.org/
# last revised     : 10.04.2012

softname='transmission'
softversion='2.51'
packageversion='72.1'

arch='i686'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download.m0k.org/transmission/files/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: BitTorrent client
$softname: 
$softname: Transmission is a free, lightweight BitTorrent client. It  
$softname: features a simple, intuitive interface on top on an efficient, 
$softname: cross-platform back-end.
$softname:  
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --program-prefix="" \
      --program-suffix="" \
      --docdir=/usr/doc/$softname-$softversion \
      --enable-nls="yes" \
      --enable-daemon="yes" \
      --enable-cli="yes" \
      --enable-gtk="yes" \
      --enable-static="no" \
      --enable-shared="yes" \
      --build=$arch-slackware-linux || exit

    make || exit 1
    make install DESTDIR=$dest
    
# add 'default' files
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Make the package freedesktop compliant
cp $dest/usr/share/pixmaps/$softname.png $dest/usr/share/icons/hicolor/48x48/apps/
rm -rf $dest/usr/share/pixmaps

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# Compress Man Pages
mv $dest/$prefix/share/man $dest/$prefix/
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# dep file
echo -e "GConf,ORBit2,atk,cairo,curl,cxxlibs|gcc-g++,cyrus-sasl,dbus,\
dbus-glib,expat,fontconfig,freetype,gcc,glib2,gtk+2,libX11,libXau,\
libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,\
libXinerama,libXrandr,libXrender,libcanberra,libevent,libidn,libnotify,\
libogg,libpng,libtool,libvorbis,libxcb,openldap-client,openssl,\
pango,pixman,zlib" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/transmission/source/build-transmission.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
